==> logtalk-3.63.0.tar.bz2: logtalk-3.63.0/ports/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


This folder contains ports of third-party libraries and applications:

* `metagol`  
	This folder contains a Logtalk port of `metagol`, an inductive
	logic programming (ILP) system based on meta-interpretive learning.

* `toychr`  
	This folder contains a Logtalk port of ToyCHR, a reference
	implementation of Constraint Handling Rules (CHR).

See the copyright and license information on the port files for usage
and distributions conditions.

The `loader.lgt` file loads all ports.

HTML documentation for each port can be found on the `docs` directory
(open the `docs/index.html` file with your web browser). The documentation
for these tools can be regenerated using the shell scripts
`../scripts/update_html_docs.sh` and `../scripts/update_svg_diagrams.sh`.

==> logtalk-3.89.1.tar.bz2: logtalk-3.89.1/ports/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


This folder contains ports of third-party libraries and applications:

* `metagol`  
	This folder contains a Logtalk port of `metagol`, an inductive
	logic programming (ILP) system based on meta-interpretive learning.

* `toychr`  
	This folder contains a Logtalk port of ToyCHR, a reference
	implementation of Constraint Handling Rules (CHR).

See the copyright and license information on the port files for usage
and distributions conditions.

The `loader.lgt` file loads all ports.

HTML documentation for each port can be found in the `docs` directory
(open the `docs/index.html` file with your web browser). The documentation
for these tools can be regenerated using the shell scripts
`../scripts/update_html_docs.sh` and `../scripts/update_svg_diagrams.sh`.
